==> webgui_7.9.33.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_Story.pm <==
package WebGUI::i18n::Dutch::Asset_Story;
use utf8;
our $I18N = {
  'Replace image with new image' => {
    'lastUpdated' => '1250240925',
    'message' => 'Vervang de afbeelding met een nieuwe'
  },
  'Source' => {
    'lastUpdated' => '1246970889',
    'message' => 'Bron'
  },
  'ago' => {
    'lastUpdated' => '1246970919',
    'message' => 'geleden'
  },
  'assetName' => {
    'lastUpdated' => '1246971009',
    'message' => 'Verhaal'
  },
  'byline' => {
    'lastUpdated' => '1246972391',
    'message' => 'Op regel'
  },
  'byline help' => {
    'lastUpdated' => '1248099234',
    'message' => 'De schrijver van het verhaal.'
  },
  'byline tmplvar' => {
    'lastUpdated' => '1248099268',
    'message' => 'De "geschreven door" regel van het verhaal.'
  },
  'bylineForm' => {
    'lastUpdated' => '1248099312',
    'message' => 'Formulier waar de gebruiker een regel in kan voeren voor het tonen van de auteur van het verhaal.'
  },
  'canEdit' => {
    'lastUpdated' => '1246974893',
    'message' => 'Een functie die aangeeft of de huidige gebruiker dit verhaal kan bewerken.'
  },
  'cancelButton' => {
    'lastUpdated' => '1246975829',
    'message' => 'Een knop waarmee de gebruiker kan annuleren zonder het formulier op te slaan.'
  },
  'crumb_loop' => {
    'lastUpdated' => '1248177919',
    'message' => 'Een functie die de route ophaalt. Het eerste element is een link naar het archief waar het veraal in zit. Het laatste element is het verhaal, met titel en url. Als er drie elementen zijn zal het middelste het onderwerp zijn.'
  },
  'crumb_title' => {
    'lastUpdated' => '1248177940',
    'message' => 'De titel van een pagina in een route.'
  },
  'crumb_url' => {
    'lastUpdated' => '1248968023',
    'message' => 'De URL van een pagina in de route.'
  },
  'edit template' => {
    'lastUpdated' => '1248178117',
    'message' => 'Bewerk verhaal sjabloon'
  },
  'formFooter' => {
    'lastUpdated' => '1248178164',
    'message' => 'HTML code om een formulier voor het bewerken of toevoegen van een verhaal te beëndigen.'
  },
  'formHeader' => {
    'lastUpdated' => '1248178189',
    'message' => 'HTML code om een formulier voor het bewerken of toevoegen van een verhaal te beginnen.<br>'
  },
  'formTitle' => {
    'lastUpdated' => '1248178639',
    'message' => 'De internationaliseerde titel van dit formulier'
  },
  'hasPhoto' => {
    'lastUpdated' => '1250240953',
    'message' => 'Deze sjabloon variabele is waar als photo_loop een foto bevat.'
  },
  'hasPhotos' => {
    'lastUpdated' => '1248178674',
    'message' => 'Deze sjabloon variabele zal waar zijn als er foto\'s aan het verhaal zijn toegevoegd.'
  },
  'headline' => {
    'lastUpdated' => '1248178596',
    'message' => 'Koptekst'
  },
  'headline help' => {
    'lastUpdated' => '1248179400',
    'message' => 'Vaak hetzelfde als de titel. Als dit leeggelaten wordt, zal de titel overgenomen worden.'
  },
  'headline tmplvar' => {
    'lastUpdated' => '1248179416',
    'message' => 'De kop van dit verhaal'
  },
  'headlineForm' => {
    'lastUpdated' => '1248179651',
    'message' => 'Formulier voor het toevoegen van een koptekst.'
  },
  'highlight' => {
    'lastUpdated' => '1248969888',
    'message' => 'Een hoogtepunt, zonder bewerking of extra HTML.'
  },
  'highlights' => {
    'lastUpdated' => '1248969902',
    'message' => 'Hoogtepunten van het verhaal'
  },
  'highlights help' => {
    'lastUpdated' => '1248969931',
    'message' => 'Korte fragmenten uit het verhaal. Voer 1 in per regel.'
  },
  'highlights tmplvar' => {
    'lastUpdated' => '1248969979',
    'message' => 'Alle hoogtepunten van het verhaal. De hoogtepunten worden gescheiden door een karakter voor een nieuwe regel.'
  },
  'highlightsForm' => {
    'lastUpdated' => '1248970027',
    'message' => 'Formulier waar de gebruiker de hoogtepunten van het verhaal kan invoeren.'
  },
  'highlights_loop' => {
    'lastUpdated' => '1248970098',
    'message' => 'Een functie die alle hoogtepunten van het verhaal ophaalt.'
  },
  'imageAlt' => {
    'lastUpdated' => '1248179773',
    'message' => 'Alternatieve tekst voor de afbeelding, geschikt voor gebruik als ALT parameter in een IMG element.'
  },
  'imageByline' => {
    'lastUpdated' => '1248968353',
    'message' => 'Een regel voor de auteur van de afbeelding.'
  },
  'imageCaption' => {
    'lastUpdated' => '1248968400',
    'message' => 'Een onderschrift voor de afbeelding.'
  },
  'imageLink' => {
    'lastUpdated' => '1248968574',
    'message' => 'Een URL waar de afbeelding naar kan linken.'
  },
  'imageTitle' => {
    'lastUpdated' => '1248099382',
    'message' => 'Alternatieve tekst voor de afbeelding, geschikt voor een TITLE eigenschap van een IMG object.'
  },
  'imageUrl' => {
    'lastUpdated' => '1246975905',
    'message' => 'De URL van de afbeelding'
  },
  'imgAltForm' => {
    'lastUpdated' => '1248968441',
    'message' => 'Een formulierveld voor alternatieve tekst voor de afbeelding, voor het ALT veld van de IMG html code.'
  },
  'imgBylineForm' => {
    'lastUpdated' => '1248968465',
    'message' => 'Een formulierveld voor de auteur van de afbeelding.'
  },
  'imgCaptionForm' => {
    'lastUpdated' => '1248968488',
    'message' => 'Een formulierveld voor het onderschrift van de afbeelding.'
  },
  'imgDeleteForm' => {
    'lastUpdated' => '1248968550',
    'message' => 'Een veld voor het verwijderen van de afbeelding en alle bijbehorende data. Dit veld is niet aanwezig in de set variabelen die hoort bij het toevoegen van afbeeldingen.'
  },
  'imgFilename' => {
    'lastUpdated' => '1250240976',
    'message' => 'De URL van de afbeelding als deze foto een afbeelding heeft.'
  },
  'imgThumb' => {
    'lastUpdated' => '1250241056',
    'message' => 'De URL van de miniatuurafbeelding als de foto een afbeelding heeft.'
  },
  'imgTitleForm' => {
    'lastUpdated' => '1248968335',
    'message' => 'Een formulierveld voor de titel van de afbeelding, voor het TITLE veld in de IMG HTML code.'
  },
  'imgUploadForm' => {
    'lastUpdated' => '1248968273',
    'message' => 'Een formulierveld om een afbeelding toe te voegen.'
  },
  'imgUrl' => {
    'lastUpdated' => '1250241031',
    'message' => 'De URL van de afbeelding als die er is.'
  },
  'imgUrlForm' => {
    'lastUpdated' => '1248968254',
    'message' => 'Een veld voor de URL van deze afbeelding. Als deze aanwezig is wordt van de afbeelding een link gemaakt naar deze URL.'
  },
  'keyword' => {
    'lastUpdated' => '1246971044',
    'message' => 'Een trefwoord zonder opmaak'
  },
  'keyword_url' => {
    'lastUpdated' => '1248179831',
    'message' => 'Een URL om alle verhalen in dit archief te bekijken die gerelateerd zijn aan dit trefwoord.'
  },
  'keywordsForm' => {
    'lastUpdated' => '1248968077',
    'message' => 'Een formulier waar trefwoorden voor dit verhaal ingevuld kunnen worden.'
  },
  'keywords_loop' => {
    'lastUpdated' => '1248968185',
    'message' => 'Een functie die alle trefwoorden van het verhaal ophaalt.'
  },
  'location' => {
    'lastUpdated' => '1246970988',
    'message' => 'Locatie'
  },
  'location help' => {
    'lastUpdated' => '1248968161',
    'message' => 'De plek waar het verhaal plaatsvindt.'
  },
  'location tmplvar' => {
    'lastUpdated' => '1248968147',
    'message' => 'De locatie uit het verhaal.'
  },
  'locationForm' => {
    'lastUpdated' => '1248179307',
    'message' => 'Een formulier waar de gebruiker een locatie van het verhaal kan opgeven.'
  },
  'newUploadForm' => {
    'lastUpdated' => '1250241006',
    'message' => 'Een formulierveld om een foto toe te voegen'
  },
  'photo alt' => {
    'lastUpdated' => '1248178713',
    'message' => 'Alternatieve tekst foto'
  },
  'photo byline' => {
    'lastUpdated' => '1248178905',
    'message' => 'Regel met maker van de foto'
  },
  'photo caption' => {
    'lastUpdated' => '1248178866',
    'message' => 'Onderschift foto'
  },
  'photo delete' => {
    'lastUpdated' => '1250240987',
    'message' => 'Verwijder foto en metadata'
  },
  'photo title' => {
    'lastUpdated' => '1248178338',
    'message' => 'Alternatieve titel foto'
  },
  'photo tmplvar' => {
    'lastUpdated' => '1248343098',
    'message' => 'De JSON data van de foto uit het verhaal asset.'
  },
  'photo url' => {
    'lastUpdated' => '1248178498',
    'message' => 'Foto URL'
  },
  'photoWidth' => {
    'lastUpdated' => '1253797571',
    'message' => 'De breedte van foto\'s, ingesteld in het verhalenarchief van dit verhaal.'
  },
  'photo_form_loop' => {
    'lastUpdated' => '1248968131',
    'message' => 'Een functie die subformulieren voor alle ingeladen foto\'s ophaalt een een leeg formulier voor het toevoegen van nieuwe foto\'s.'
  },
  'photo_loop' => {
    'lastUpdated' => '1248179864',
    'message' => 'Een functie die foto\'s en informatie over foto\'s ophaalt.'
  },
  'save and add another photo' => {
    'lastUpdated' => '1248178373',
    'message' => 'Opslaan en nog een foto toevoegen'
  },
  'save story' => {
    'lastUpdated' => '1248178313',
    'message' => 'Verhaal opslaan'
  },
  'saveAndAddButton' => {
    'lastUpdated' => '1248178449',
    'message' => 'Knop waarme de gebruiker het formulier opslaat en heropend om nog een foto toe te voegen.'
  },
  'saveButton' => {
    'lastUpdated' => '1248178302',
    'message' => 'Knop waar de gebruiker het formulier mee kan opslaan.'
  },
  'singlePhoto' => {
    'lastUpdated' => '1248178271',
    'message' => 'Deze sjabloon variabele is waar als er maar 1 foto aan het verhaal is toegevoegd.'
  },
  'storageId tmplvar' => {
    'lastUpdated' => '1248351587',
    'message' => 'De unieke opslag Id (storageId) van de foto van de asset.'
  },
  'story' => {
    'lastUpdated' => '1248178222',
    'message' => 'Verhaal'
  },
  'story asset template variables title' => {
    'lastUpdated' => '1248178731',
    'message' => 'Verhaal sjabloon variabelen'
  },
  'story help' => {
    'lastUpdated' => '1248968043',
    'message' => 'Het verhaal'
  },
  'story received' => {
    'lastUpdated' => '1248178570',
    'message' => 'Uw verhaal is ontvangen en wordt verwerkt zodat het aan de site kan worden toegevoegd. Het zal beschikbaar zijn voor verdere bewerking als het verwerkt is. Geduld alstublieft.'
  },
  'story tmplvar' => {
    'lastUpdated' => '1248342162',
    'message' => 'Het verhaal. Het kan extra inhooud bevatten die er met de Rich Text Editor is ingezet.'
  },
  'storyForm' => {
    'lastUpdated' => '1248180077',
    'message' => 'Formulier waar het eigenlijke verhaal kan worden ingevoerd.'
  },
  'subtitle' => {
    'lastUpdated' => '1248178208',
    'message' => 'Ondertitel'
  },
  'subtitle help' => {
    'lastUpdated' => '1248179889',
    'message' => 'Gelijk aan de koptekst, maar bevat normaliter meer informatie.'
  },
  'subtitle tmplvar' => {
    'lastUpdated' => '1248179907',
    'message' => 'De ondertitel van een verhaal.'
  },
  'subtitleForm' => {
    'lastUpdated' => '1248179954',
    'message' => 'Formulier waarmee een ondertitel aan dit verhaal kan worde toegevoegd.'
  },
  'summaryForm' => {
    'lastUpdated' => '1248179992',
    'message' => 'Formulier voor het toevoegen van een samenvatting van dit verhaal.'
  },
  'titleForm' => {
    'lastUpdated' => '1248178413',
    'message' => 'Formulier waar een gebruiker een titel van het verhaal kan opgeven.'
  },
  'updatedTime' => {
    'lastUpdated' => '1248179352',
    'message' => 'De tijd waarop dit verhaal is bijgewerkt, in tijd geleden, zoals 1 uur geleden.'
  },
  'updatedTimeEpoch' => {
    'lastUpdated' => '1248180047',
    'message' => 'De tijd waarop dit verhaal is bijgwerkt, als epoch tijd.'
  },
  'view template' => {
    'lastUpdated' => '1246970968',
    'message' => 'Bekijk verhaal sjabloon'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Dutch/Asset_Story.pm <==
package WebGUI::i18n::Dutch::Asset_Story;
use utf8;
our $I18N = {
  'Replace image with new image' => {
    'lastUpdated' => '1250240925',
    'message' => 'Vervang de afbeelding met een nieuwe'
  },
  'Source' => {
    'lastUpdated' => '1246970889',
    'message' => 'Bron'
  },
  'ago' => {
    'lastUpdated' => '1246970919',
    'message' => 'geleden'
  },
  'assetName' => {
    'lastUpdated' => '1246971009',
    'message' => 'Verhaal'
  },
  'byline' => {
    'lastUpdated' => '1246972391',
    'message' => 'Op regel'
  },
  'byline help' => {
    'lastUpdated' => '1248099234',
    'message' => 'De schrijver van het verhaal.'
  },
  'byline tmplvar' => {
    'lastUpdated' => '1248099268',
    'message' => 'De "geschreven door" regel van het verhaal.'
  },
  'bylineForm' => {
    'lastUpdated' => '1248099312',
    'message' => 'Formulier waar de gebruiker een regel in kan voeren voor het tonen van de auteur van het verhaal.'
  },
  'canEdit' => {
    'lastUpdated' => '1246974893',
    'message' => 'Een functie die aangeeft of de huidige gebruiker dit verhaal kan bewerken.'
  },
  'cancelButton' => {
    'lastUpdated' => '1246975829',
    'message' => 'Een knop waarmee de gebruiker kan annuleren zonder het formulier op te slaan.'
  },
  'crumb_loop' => {
    'lastUpdated' => '1248177919',
    'message' => 'Een functie die de route ophaalt. Het eerste element is een link naar het archief waar het veraal in zit. Het laatste element is het verhaal, met titel en url. Als er drie elementen zijn zal het middelste het onderwerp zijn.'
  },
  'crumb_title' => {
    'lastUpdated' => '1248177940',
    'message' => 'De titel van een pagina in een route.'
  },
  'crumb_url' => {
    'lastUpdated' => '1248968023',
    'message' => 'De URL van een pagina in de route.'
  },
  'edit template' => {
    'lastUpdated' => '1248178117',
    'message' => 'Bewerk verhaal sjabloon'
  },
  'formFooter' => {
    'lastUpdated' => '1248178164',
    'message' => 'HTML code om een formulier voor het bewerken of toevoegen van een verhaal te beëndigen.'
  },
  'formHeader' => {
    'lastUpdated' => '1248178189',
    'message' => 'HTML code om een formulier voor het bewerken of toevoegen van een verhaal te beginnen.<br>'
  },
  'formTitle' => {
    'lastUpdated' => '1248178639',
    'message' => 'De internationaliseerde titel van dit formulier'
  },
  'hasPhoto' => {
    'lastUpdated' => '1250240953',
    'message' => 'Deze sjabloon variabele is waar als photo_loop een foto bevat.'
  },
  'hasPhotos' => {
    'lastUpdated' => '1248178674',
    'message' => 'Deze sjabloon variabele zal waar zijn als er foto\'s aan het verhaal zijn toegevoegd.'
  },
  'headline' => {
    'lastUpdated' => '1248178596',
    'message' => 'Koptekst'
  },
  'headline help' => {
    'lastUpdated' => '1248179400',
    'message' => 'Vaak hetzelfde als de titel. Als dit leeggelaten wordt, zal de titel overgenomen worden.'
  },
  'headline tmplvar' => {
    'lastUpdated' => '1248179416',
    'message' => 'De kop van dit verhaal'
  },
  'headlineForm' => {
    'lastUpdated' => '1248179651',
    'message' => 'Formulier voor het toevoegen van een koptekst.'
  },
  'highlight' => {
    'lastUpdated' => '1248969888',
    'message' => 'Een hoogtepunt, zonder bewerking of extra HTML.'
  },
  'highlights' => {
    'lastUpdated' => '1248969902',
    'message' => 'Hoogtepunten van het verhaal'
  },
  'highlights help' => {
    'lastUpdated' => '1248969931',
    'message' => 'Korte fragmenten uit het verhaal. Voer 1 in per regel.'
  },
  'highlights tmplvar' => {
    'lastUpdated' => '1248969979',
    'message' => 'Alle hoogtepunten van het verhaal. De hoogtepunten worden gescheiden door een karakter voor een nieuwe regel.'
  },
  'highlightsForm' => {
    'lastUpdated' => '1248970027',
    'message' => 'Formulier waar de gebruiker de hoogtepunten van het verhaal kan invoeren.'
  },
  'highlights_loop' => {
    'lastUpdated' => '1248970098',
    'message' => 'Een functie die alle hoogtepunten van het verhaal ophaalt.'
  },
  'imageAlt' => {
    'lastUpdated' => '1248179773',
    'message' => 'Alternatieve tekst voor de afbeelding, geschikt voor gebruik als ALT parameter in een IMG element.'
  },
  'imageByline' => {
    'lastUpdated' => '1248968353',
    'message' => 'Een regel voor de auteur van de afbeelding.'
  },
  'imageCaption' => {
    'lastUpdated' => '1248968400',
    'message' => 'Een onderschrift voor de afbeelding.'
  },
  'imageLink' => {
    'lastUpdated' => '1248968574',
    'message' => 'Een URL waar de afbeelding naar kan linken.'
  },
  'imageTitle' => {
    'lastUpdated' => '1248099382',
    'message' => 'Alternatieve tekst voor de afbeelding, geschikt voor een TITLE eigenschap van een IMG object.'
  },
  'imageUrl' => {
    'lastUpdated' => '1246975905',
    'message' => 'De URL van de afbeelding'
  },
  'imgAltForm' => {
    'lastUpdated' => '1248968441',
    'message' => 'Een formulierveld voor alternatieve tekst voor de afbeelding, voor het ALT veld van de IMG html code.'
  },
  'imgBylineForm' => {
    'lastUpdated' => '1248968465',
    'message' => 'Een formulierveld voor de auteur van de afbeelding.'
  },
  'imgCaptionForm' => {
    'lastUpdated' => '1248968488',
    'message' => 'Een formulierveld voor het onderschrift van de afbeelding.'
  },
  'imgDeleteForm' => {
    'lastUpdated' => '1248968550',
    'message' => 'Een veld voor het verwijderen van de afbeelding en alle bijbehorende data. Dit veld is niet aanwezig in de set variabelen die hoort bij het toevoegen van afbeeldingen.'
  },
  'imgFilename' => {
    'lastUpdated' => '1250240976',
    'message' => 'De URL van de afbeelding als deze foto een afbeelding heeft.'
  },
  'imgRemoteUrlForm' => {
    'lastUpdated' => '1304600525',
    'message' => 'Een formulierveld voor het specificeren van een URL van een foto.'
  },
  'imgThumb' => {
    'lastUpdated' => '1250241056',
    'message' => 'De URL van de miniatuurafbeelding als de foto een afbeelding heeft.'
  },
  'imgTitleForm' => {
    'lastUpdated' => '1248968335',
    'message' => 'Een formulierveld voor de titel van de afbeelding, voor het TITLE veld in de IMG HTML code.'
  },
  'imgUploadForm' => {
    'lastUpdated' => '1248968273',
    'message' => 'Een formulierveld om een afbeelding toe te voegen.'
  },
  'imgUrl' => {
    'lastUpdated' => '1250241031',
    'message' => 'De URL van de afbeelding als die er is.'
  },
  'imgUrlForm' => {
    'lastUpdated' => '1248968254',
    'message' => 'Een veld voor de URL van deze afbeelding. Als deze aanwezig is wordt van de afbeelding een link gemaakt naar deze URL.'
  },
  'keyword' => {
    'lastUpdated' => '1246971044',
    'message' => 'Een trefwoord zonder opmaak'
  },
  'keyword_url' => {
    'lastUpdated' => '1248179831',
    'message' => 'Een URL om alle verhalen in dit archief te bekijken die gerelateerd zijn aan dit trefwoord.'
  },
  'keywordsForm' => {
    'lastUpdated' => '1248968077',
    'message' => 'Een formulier waar trefwoorden voor dit verhaal ingevuld kunnen worden.'
  },
  'keywords_loop' => {
    'lastUpdated' => '1248968185',
    'message' => 'Een functie die alle trefwoorden van het verhaal ophaalt.'
  },
  'location' => {
    'lastUpdated' => '1246970988',
    'message' => 'Locatie'
  },
  'location help' => {
    'lastUpdated' => '1248968161',
    'message' => 'De plek waar het verhaal plaatsvindt.'
  },
  'location tmplvar' => {
    'lastUpdated' => '1248968147',
    'message' => 'De locatie uit het verhaal.'
  },
  'locationForm' => {
    'lastUpdated' => '1248179307',
    'message' => 'Een formulier waar de gebruiker een locatie van het verhaal kan opgeven.'
  },
  'newUploadForm' => {
    'lastUpdated' => '1250241006',
    'message' => 'Een formulierveld om een foto toe te voegen'
  },
  'photo alt' => {
    'lastUpdated' => '1248178713',
    'message' => 'Alternatieve tekst foto'
  },
  'photo byline' => {
    'lastUpdated' => '1248178905',
    'message' => 'Regel met maker van de foto'
  },
  'photo caption' => {
    'lastUpdated' => '1248178866',
    'message' => 'Onderschift foto'
  },
  'photo delete' => {
    'lastUpdated' => '1250240987',
    'message' => 'Verwijder foto en metadata'
  },
  'photo remote url' => {
    'lastUpdated' => '1304600543',
    'message' => 'Foto URL'
  },
  'photo title' => {
    'lastUpdated' => '1248178338',
    'message' => 'Alternatieve titel foto'
  },
  'photo tmplvar' => {
    'lastUpdated' => '1248343098',
    'message' => 'De JSON data van de foto uit het verhaal asset.'
  },
  'photo url' => {
    'lastUpdated' => '1248178498',
    'message' => 'Foto URL'
  },
  'photoWidth' => {
    'lastUpdated' => '1253797571',
    'message' => 'De breedte van foto\'s, ingesteld in het verhalenarchief van dit verhaal.'
  },
  'photo_form_loop' => {
    'lastUpdated' => '1248968131',
    'message' => 'Een functie die subformulieren voor alle ingeladen foto\'s ophaalt een een leeg formulier voor het toevoegen van nieuwe foto\'s.'
  },
  'photo_loop' => {
    'lastUpdated' => '1248179864',
    'message' => 'Een functie die foto\'s en informatie over foto\'s ophaalt.'
  },
  'save and add another photo' => {
    'lastUpdated' => '1248178373',
    'message' => 'Opslaan en nog een foto toevoegen'
  },
  'save story' => {
    'lastUpdated' => '1248178313',
    'message' => 'Verhaal opslaan'
  },
  'saveAndAddButton' => {
    'lastUpdated' => '1248178449',
    'message' => 'Knop waarme de gebruiker het formulier opslaat en heropend om nog een foto toe te voegen.'
  },
  'saveButton' => {
    'lastUpdated' => '1248178302',
    'message' => 'Knop waar de gebruiker het formulier mee kan opslaan.'
  },
  'singlePhoto' => {
    'lastUpdated' => '1248178271',
    'message' => 'Deze sjabloon variabele is waar als er maar 1 foto aan het verhaal is toegevoegd.'
  },
  'storageId tmplvar' => {
    'lastUpdated' => '1248351587',
    'message' => 'De unieke opslag Id (storageId) van de foto van de asset.'
  },
  'story' => {
    'lastUpdated' => '1248178222',
    'message' => 'Verhaal'
  },
  'story asset template variables title' => {
    'lastUpdated' => '1248178731',
    'message' => 'Verhaal sjabloon variabelen'
  },
  'story help' => {
    'lastUpdated' => '1248968043',
    'message' => 'Het verhaal'
  },
  'story received' => {
    'lastUpdated' => '1248178570',
    'message' => 'Uw verhaal is ontvangen en wordt verwerkt zodat het aan de site kan worden toegevoegd. Het zal beschikbaar zijn voor verdere bewerking als het verwerkt is. Geduld alstublieft.'
  },
  'story tmplvar' => {
    'lastUpdated' => '1248342162',
    'message' => 'Het verhaal. Het kan extra inhooud bevatten die er met de Rich Text Editor is ingezet.'
  },
  'storyForm' => {
    'lastUpdated' => '1248180077',
    'message' => 'Formulier waar het eigenlijke verhaal kan worden ingevoerd.'
  },
  'subtitle' => {
    'lastUpdated' => '1248178208',
    'message' => 'Ondertitel'
  },
  'subtitle help' => {
    'lastUpdated' => '1248179889',
    'message' => 'Gelijk aan de koptekst, maar bevat normaliter meer informatie.'
  },
  'subtitle tmplvar' => {
    'lastUpdated' => '1248179907',
    'message' => 'De ondertitel van een verhaal.'
  },
  'subtitleForm' => {
    'lastUpdated' => '1248179954',
    'message' => 'Formulier waarmee een ondertitel aan dit verhaal kan worde toegevoegd.'
  },
  'summaryForm' => {
    'lastUpdated' => '1248179992',
    'message' => 'Formulier voor het toevoegen van een samenvatting van dit verhaal.'
  },
  'titleForm' => {
    'lastUpdated' => '1248178413',
    'message' => 'Formulier waar een gebruiker een titel van het verhaal kan opgeven.'
  },
  'updatedTime' => {
    'lastUpdated' => '1248179352',
    'message' => 'De tijd waarop dit verhaal is bijgewerkt, in tijd geleden, zoals 1 uur geleden.'
  },
  'updatedTimeEpoch' => {
    'lastUpdated' => '1248180047',
    'message' => 'De tijd waarop dit verhaal is bijgwerkt, als epoch tijd.'
  },
  'view template' => {
    'lastUpdated' => '1246970968',
    'message' => 'Bekijk verhaal sjabloon'
  }
}
;

1;
